==> gatsby-theme-platformos-docskit-1.1.2.tgz: package/gatsby-config.js <==
/**
 * Configure your Gatsby site with this file.
 *
 * See: https://www.gatsbyjs.com/docs/reference/config-files/gatsby-config/
 */
const path = require('path');

/**
 * @type {import('gatsby').GatsbyConfig}
 */
module.exports = themeConfig => {
  const defaultThemeConfig = {
    useLegacyUrls: false,
    showFullNavigation: false
  };

  return ({
    siteMetadata: {
      title: 'platformOS DocsKit',
      description: 'DocsKit',
      author: 'platformOS',
      themeConfig: {
        ...defaultThemeConfig,
        ...themeConfig
      }
    },
    plugins: [
      'gatsby-plugin-postcss',
      'gatsby-plugin-image',
      {
        resolve: 'gatsby-plugin-alias-imports',
        options: {
          alias: {
            '@partials': 'partials',
            '@components': path.join(__dirname, './src/components')
          },
          extensions: ['.mdx']
        }
      },
      {
        resolve: 'gatsby-plugin-mdx',
        options: {
          extensions: ['.mdx', '.md'],
          gatsbyRemarkPlugins: [
            {
              resolve: 'gatsby-remark-images',
              options: {
                maxWidth: 704,
                disableBgImageOnAlpha: true,
                linkImagesToOriginal: false,
                backgroundColor: 'transparent'
              }
            },
            'gatsby-remark-autolink-headers',
            'gatsby-remark-embed-video',
            'gatsby-remark-responsive-iframe',
            'gatsby-remark-external-links',
            {
              resolve: `gatsby-remark-prismjs`,
              options: {
                classPrefix: "language-",
                inlineCodeMarker: null,
                aliases: {},
                showLineNumbers: false,
                noInlineHighlight: true,
                languageExtensions: [],
                prompt: {
                  user: "root",
                  host: "localhost",
                  global: false,
                },
                escapeEntities: {},
              },
            }
          ]
        }
      },
      'gatsby-plugin-mdx-source-name',
      {
        resolve: 'gatsby-source-filesystem',
        options: {
          path: 'docs',
          name: 'content'
        }
      },
      {
        resolve: 'gatsby-source-filesystem',
        options: {
          path: 'partials',
          name: 'partials'
        }
      },
      'gatsby-transformer-sharp',
      'gatsby-plugin-sharp',
    ],
  });
};

==> gatsby-theme-platformos-docskit-1.1.6.tgz: package/gatsby-config.js <==
/**
 * Configure your Gatsby site with this file.
 *
 * See: https://www.gatsbyjs.com/docs/reference/config-files/gatsby-config/
 */
const path = require('path');

/**
 * @type {import('gatsby').GatsbyConfig}
 */
module.exports = themeConfig => {
  const defaultThemeConfig = {
    useLegacyUrls: false,
    showFullNavigation: false,
    basePath: ''
  };

  return ({
    siteMetadata: {
      title: 'platformOS DocsKit',
      description: 'DocsKit',
      author: 'platformOS',
      themeConfig: {
        ...defaultThemeConfig,
        ...themeConfig
      }
    },
    plugins: [
      'gatsby-plugin-postcss',
      'gatsby-plugin-image',
      {
        resolve: 'gatsby-plugin-alias-imports',
        options: {
          alias: {
            '@partials': 'partials',
            '@components': path.join(__dirname, './src/components')
          },
          extensions: ['.mdx']
        }
      },
      {
        resolve: 'gatsby-plugin-mdx',
        options: {
          extensions: ['.mdx', '.md'],
          gatsbyRemarkPlugins: [
            {
              resolve: 'gatsby-remark-images',
              options: {
                maxWidth: 1024,
                disableBgImageOnAlpha: true,
                linkImagesToOriginal: false,
                backgroundColor: 'transparent',
                withWebp: true,
                withAvif: true,
                srcSetBreakpoints: [320, 640]
              }
            },
            'gatsby-remark-autolink-headers',
            'gatsby-remark-embed-video',
            'gatsby-remark-responsive-iframe',
            'gatsby-remark-external-links',
            {
              resolve: `gatsby-remark-prismjs`,
              options: {
                classPrefix: "language-",
                inlineCodeMarker: null,
                aliases: {},
                showLineNumbers: false,
                noInlineHighlight: true,
                languageExtensions: [],
                prompt: {
                  user: "root",
                  host: "localhost",
                  global: false,
                },
                escapeEntities: {},
              },
            },
            {
              resolve: require.resolve(`./plugins/pos-fix-remark-path-prefix-plugin`),
              options: {
                basePath: themeConfig.basePath
              }
            }
          ]
        }
      },
      'gatsby-plugin-mdx-source-name',
      {
        resolve: 'gatsby-source-filesystem',
        options: {
          path: 'docs',
          name: 'content'
        }
      },
      {
        resolve: 'gatsby-source-filesystem',
        options: {
          path: 'partials',
          name: 'partials'
        }
      },
      'gatsby-transformer-sharp',
      'gatsby-plugin-sharp',
    ],
  });
};
